#!/bin/sh

if [ ! -f /var/log/nvidia ] && [ ! -f /var/log/nvidia-470xx ] \
    && [ ! -f /var/log/nvidia-580xx ] && [ ! -f /var/log/nvidia-prime ]; then
    sudo sed -i -e 's|- packagechooserq@licenseq|#- packagechooserq@licenseq|' /usr/share/calamares/settings.conf
fi

#if ! ping -c 1 "8.8.8.8" > /dev/null; then
#    sudo sed -i -e 's|- localeq|- locale|' /usr/share/calamares/settings.conf
#fi

if [ ! -d /sys/firmware/efi/efivars ]; then
    sudo sed -i -e 's|"xfs","ext4","zfs"|"ext4"|' /usr/share/calamares/modules/partition.conf
    sudo sed -i -e 's|defaultFileSystemType:  "xfs"|defaultFileSystemType:  "ext4"|' /usr/share/calamares/modules/partition.conf
fi

pkexec --disable-internal-agent env \
    DBUS_SESSION_BUS_ADDRESS="$DBUS_SESSION_BUS_ADDRESS" \
    WAYLAND_DISPLAY="$WAYLAND_DISPLAY" \
    XDG_RUNTIME_DIR="$XDG_RUNTIME_DIR" \
    HOME="$HOME" \
    QT_STYLE_OVERRIDE="$QT_STYLE_OVERRIDE" \
    QT_QPA_PLATFORMTHEME="$QT_QPA_PLATFORMTHEME" \
    QT_QPA_PLATFORM="wayland" \
    XDG_CURRENT_DESKTOP="$XDG_CURRENT_DESKTOP" \
    XDG_SESSION_TYPE="wayland" \
    "/usr/bin/calamares" "-D6" "$@" > installation.log
